# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.hub_spot_actor_id_response import HubSpotActorIdResponse

class TestHubSpotActorIdResponse(unittest.TestCase):
    """HubSpotActorIdResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HubSpotActorIdResponse:
        """Test HubSpotActorIdResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `HubSpotActorIdResponse`
        """
        model = HubSpotActorIdResponse()
        if include_optional:
            return HubSpotActorIdResponse(
                actor_id = '',
                actor_email = ''
            )
        else:
            return HubSpotActorIdResponse(
                actor_id = '',
                actor_email = '',
        )
        """

    def testHubSpotActorIdResponse(self):
        """Test HubSpotActorIdResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
