# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.tags_api import TagsApi


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TagsApi()

    def tearDown(self) -> None:
        pass

    def test_create_tag(self) -> None:
        """Test case for create_tag

        Create Tag
        """
        pass

    def test_delete_tag(self) -> None:
        """Test case for delete_tag

        Delete Tag
        """
        pass

    def test_search_tags(self) -> None:
        """Test case for search_tags

        Search Tags
        """
        pass

    def test_update_tag(self) -> None:
        """Test case for update_tag

        Update Tag
        """
        pass


if __name__ == '__main__':
    unittest.main()
