# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class TrackingEventData(BaseModel):
    """
    Value object for tracking event data
    """ # noqa: E501
    key: StrictStr
    value_text: Optional[StrictStr] = None
    value_number: Optional[Union[StrictFloat, StrictInt]] = None
    value_boolean: Optional[StrictBool] = None
    value_datetime: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["key", "value_text", "value_number", "value_boolean", "value_datetime"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TrackingEventData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if value_text (nullable) is None
        # and model_fields_set contains the field
        if self.value_text is None and "value_text" in self.model_fields_set:
            _dict['value_text'] = None

        # set to None if value_number (nullable) is None
        # and model_fields_set contains the field
        if self.value_number is None and "value_number" in self.model_fields_set:
            _dict['value_number'] = None

        # set to None if value_boolean (nullable) is None
        # and model_fields_set contains the field
        if self.value_boolean is None and "value_boolean" in self.model_fields_set:
            _dict['value_boolean'] = None

        # set to None if value_datetime (nullable) is None
        # and model_fields_set contains the field
        if self.value_datetime is None and "value_datetime" in self.model_fields_set:
            _dict['value_datetime'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TrackingEventData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "key": obj.get("key"),
            "value_text": obj.get("value_text"),
            "value_number": obj.get("value_number"),
            "value_boolean": obj.get("value_boolean"),
            "value_datetime": obj.get("value_datetime")
        })
        return _obj


