# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.workspaces_sso_domain_verification_api import WorkspacesSSODomainVerificationApi


class TestWorkspacesSSODomainVerificationApi(unittest.TestCase):
    """WorkspacesSSODomainVerificationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkspacesSSODomainVerificationApi()

    def tearDown(self) -> None:
        pass

    def test_create_domain_verification(self) -> None:
        """Test case for create_domain_verification

        Create Domain Verification
        """
        pass

    def test_delete_domain_verification(self) -> None:
        """Test case for delete_domain_verification

        Delete Domain Verification
        """
        pass

    def test_list_domain_verifications(self) -> None:
        """Test case for list_domain_verifications

        List Domain Verifications
        """
        pass

    def test_verify_domain(self) -> None:
        """Test case for verify_domain

        Verify Domain
        """
        pass


if __name__ == '__main__':
    unittest.main()
