# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.schedules_api import SchedulesApi


class TestSchedulesApi(unittest.TestCase):
    """SchedulesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SchedulesApi()

    def tearDown(self) -> None:
        pass

    def test_create_schedules(self) -> None:
        """Test case for create_schedules

        Create Schedules
        """
        pass

    def test_delete_schedule(self) -> None:
        """Test case for delete_schedule

        Delete Schedule
        """
        pass

    def test_get_schedule(self) -> None:
        """Test case for get_schedule

        Get Schedule
        """
        pass

    def test_get_schedule_url_details(self) -> None:
        """Test case for get_schedule_url_details

        Get Schedule Url Details
        """
        pass

    def test_get_schedules(self) -> None:
        """Test case for get_schedules

        Get Schedules
        """
        pass

    def test_run_schedule(self) -> None:
        """Test case for run_schedule

        Run Schedule
        """
        pass

    def test_search_schedule_urls(self) -> None:
        """Test case for search_schedule_urls

        Search Schedule Urls
        """
        pass

    def test_update_schedule(self) -> None:
        """Test case for update_schedule

        Update Schedule
        """
        pass


if __name__ == '__main__':
    unittest.main()
