# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.serp_search_requests import SerpSearchRequests

class TestSerpSearchRequests(unittest.TestCase):
    """SerpSearchRequests unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SerpSearchRequests:
        """Test SerpSearchRequests
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SerpSearchRequests`
        """
        model = SerpSearchRequests()
        if include_optional:
            return SerpSearchRequests(
                requests = [
                    flowhunt.models.serp_search_request.SerpSearchRequest(
                        post_back_url = '', 
                        query = 'liveagent help desk software', 
                        country = '', 
                        location = '', 
                        language = '', 
                        count_urls = 56, )
                    ],
                live_mode = True
            )
        else:
            return SerpSearchRequests(
                requests = [
                    flowhunt.models.serp_search_request.SerpSearchRequest(
                        post_back_url = '', 
                        query = 'liveagent help desk software', 
                        country = '', 
                        location = '', 
                        language = '', 
                        count_urls = 56, )
                    ],
        )
        """

    def testSerpSearchRequests(self):
        """Test SerpSearchRequests"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
