# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FlowAssistantAIModel(str, Enum):
    """
    FlowAssistantAIModel
    """

    """
    allowed enum values
    """
    CLAUDE_3_DOT_5_SONNET = 'Claude 3.5 Sonnet'
    CLAUDE_3_DOT_7_SONNET = 'Claude 3.7 Sonnet'
    GPT4_DOT_1 = 'GPT4.1'
    O4_MINI = 'O4 Mini'
    O3_MINI = 'O3 Mini'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FlowAssistantAIModel from a JSON string"""
        return cls(json.loads(json_str))


