# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.tracking_sources_response import TrackingSourcesResponse

class TestTrackingSourcesResponse(unittest.TestCase):
    """TrackingSourcesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TrackingSourcesResponse:
        """Test TrackingSourcesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TrackingSourcesResponse`
        """
        model = TrackingSourcesResponse()
        if include_optional:
            return TrackingSourcesResponse(
                sources = [
                    flowhunt.models.tracking_source_response.TrackingSourceResponse(
                        customer_id = '', 
                        link_id = '', 
                        source_type = 'ga', 
                        click_id = '', 
                        click_id_name = 'gclid', 
                        utm_source = '', 
                        utm_medium = '', 
                        utm_campaign = '', 
                        utm_term = '', 
                        utm_content = '', 
                        utm_channel = '', 
                        ga = '', 
                        url = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        valid_until = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        event_data = [
                            flowhunt.models.tracking_event_data.TrackingEventData(
                                key = '', 
                                value_text = '', 
                                value_number = 1.337, 
                                value_boolean = True, 
                                value_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], )
                    ]
            )
        else:
            return TrackingSourcesResponse(
                sources = [
                    flowhunt.models.tracking_source_response.TrackingSourceResponse(
                        customer_id = '', 
                        link_id = '', 
                        source_type = 'ga', 
                        click_id = '', 
                        click_id_name = 'gclid', 
                        utm_source = '', 
                        utm_medium = '', 
                        utm_campaign = '', 
                        utm_term = '', 
                        utm_content = '', 
                        utm_channel = '', 
                        ga = '', 
                        url = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        valid_until = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        event_data = [
                            flowhunt.models.tracking_event_data.TrackingEventData(
                                key = '', 
                                value_text = '', 
                                value_number = 1.337, 
                                value_boolean = True, 
                                value_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], )
                    ],
        )
        """

    def testTrackingSourcesResponse(self):
        """Test TrackingSourcesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
