# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.word_press_api import WordPressApi


class TestWordPressApi(unittest.TestCase):
    """WordPressApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WordPressApi()

    def tearDown(self) -> None:
        pass

    def test_get_wordpress_post_categories(self) -> None:
        """Test case for get_wordpress_post_categories

        Get Wordpress Post Categories
        """
        pass

    def test_get_wordpress_post_tags(self) -> None:
        """Test case for get_wordpress_post_tags

        Get Wordpress Post Tags
        """
        pass

    def test_get_wordpress_sites(self) -> None:
        """Test case for get_wordpress_sites

        Get Wordpress Sites
        """
        pass


if __name__ == '__main__':
    unittest.main()
