# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.google_ads_match_type import GoogleAdsMatchType
from typing import Optional, Set
from typing_extensions import Self

class GoogleAdsKeywordAddRequest(BaseModel):
    """
    GoogleAdsKeywordAddRequest
    """ # noqa: E501
    customer_id: StrictStr = Field(description="Customer id")
    campaign_id: StrictStr = Field(description="Campaign id")
    group_id: StrictStr = Field(description="Group id")
    keywords: List[StrictStr] = Field(description="List of keywords to add")
    is_negative: Optional[StrictBool] = Field(default=False, description="Is negative keyword")
    match_type: GoogleAdsMatchType = Field(description="Match type")
    __properties: ClassVar[List[str]] = ["customer_id", "campaign_id", "group_id", "keywords", "is_negative", "match_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GoogleAdsKeywordAddRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GoogleAdsKeywordAddRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "customer_id": obj.get("customer_id"),
            "campaign_id": obj.get("campaign_id"),
            "group_id": obj.get("group_id"),
            "keywords": obj.get("keywords"),
            "is_negative": obj.get("is_negative") if obj.get("is_negative") is not None else False,
            "match_type": obj.get("match_type")
        })
        return _obj


