# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.serp_search_request import SerpSearchRequest

class TestSerpSearchRequest(unittest.TestCase):
    """SerpSearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SerpSearchRequest:
        """Test SerpSearchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SerpSearchRequest`
        """
        model = SerpSearchRequest()
        if include_optional:
            return SerpSearchRequest(
                post_back_url = '',
                query = 'liveagent help desk software',
                country = '',
                location = '',
                language = '',
                count_urls = 56
            )
        else:
            return SerpSearchRequest(
                query = 'liveagent help desk software',
        )
        """

    def testSerpSearchRequest(self):
        """Test SerpSearchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
