# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.prompts_api import PromptsApi


class TestPromptsApi(unittest.TestCase):
    """PromptsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PromptsApi()

    def tearDown(self) -> None:
        pass

    def test_create_prompt(self) -> None:
        """Test case for create_prompt

        Create Prompt
        """
        pass

    def test_create_prompt_category(self) -> None:
        """Test case for create_prompt_category

        Create Prompt Category
        """
        pass

    def test_delete_prompt(self) -> None:
        """Test case for delete_prompt

        Delete Prompt
        """
        pass

    def test_delete_prompt_category(self) -> None:
        """Test case for delete_prompt_category

        Delete Prompt Category
        """
        pass

    def test_search_prompt_categories(self) -> None:
        """Test case for search_prompt_categories

        Search Prompt Categories
        """
        pass

    def test_search_prompts(self) -> None:
        """Test case for search_prompts

        Search Prompts
        """
        pass

    def test_update_prompt(self) -> None:
        """Test case for update_prompt

        Update Prompt
        """
        pass

    def test_update_prompt_category(self) -> None:
        """Test case for update_prompt_category

        Update Prompt Category
        """
        pass


if __name__ == '__main__':
    unittest.main()
