# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.workspace_sso_create_request import WorkspaceSSOCreateRequest

class TestWorkspaceSSOCreateRequest(unittest.TestCase):
    """WorkspaceSSOCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkspaceSSOCreateRequest:
        """Test WorkspaceSSOCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorkspaceSSOCreateRequest`
        """
        model = WorkspaceSSOCreateRequest()
        if include_optional:
            return WorkspaceSSOCreateRequest(
                provider = '',
                enabled = True,
                idp_sso_url = '',
                jit_provisioning_enabled = True,
                email_attribute = '',
                name_id_format = '',
                first_name_attribute = '',
                last_name_attribute = '',
                role_attribute = '',
                login_method = 'f',
                idp_metadata_xml = ''
            )
        else:
            return WorkspaceSSOCreateRequest(
                provider = '',
        )
        """

    def testWorkspaceSSOCreateRequest(self):
        """Test WorkspaceSSOCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
