# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.web_auth_api import WebAuthApi


class TestWebAuthApi(unittest.TestCase):
    """WebAuthApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WebAuthApi()

    def tearDown(self) -> None:
        pass

    def test_activate_account(self) -> None:
        """Test case for activate_account

        Activate Account
        """
        pass

    def test_get_user(self) -> None:
        """Test case for get_user

        Get User
        """
        pass

    def test_password_recovery_page(self) -> None:
        """Test case for password_recovery_page

        Password Recovery Page
        """
        pass

    def test_password_recovery_submit(self) -> None:
        """Test case for password_recovery_submit

        Password Recovery Submit
        """
        pass

    def test_register_page(self) -> None:
        """Test case for register_page

        Register Page
        """
        pass

    def test_register_submit(self) -> None:
        """Test case for register_submit

        Register Submit
        """
        pass

    def test_reset_password_page(self) -> None:
        """Test case for reset_password_page

        Reset Password Page
        """
        pass

    def test_reset_password_submit(self) -> None:
        """Test case for reset_password_submit

        Reset Password Submit
        """
        pass

    def test_sso_login_page(self) -> None:
        """Test case for sso_login_page

        Sso Login Page
        """
        pass

    def test_sso_login_submit(self) -> None:
        """Test case for sso_login_submit

        Sso Login Submit
        """
        pass


if __name__ == '__main__':
    unittest.main()
