# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.inference_history_search_request import InferenceHistorySearchRequest

class TestInferenceHistorySearchRequest(unittest.TestCase):
    """InferenceHistorySearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InferenceHistorySearchRequest:
        """Test InferenceHistorySearchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InferenceHistorySearchRequest`
        """
        model = InferenceHistorySearchRequest()
        if include_optional:
            return InferenceHistorySearchRequest(
                from_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                to_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                limit = 56,
                search_after = [
                    null
                    ],
                base_model = 'flux-dev',
                style = '',
                effect = '',
                aspect_ratio = '1:1'
            )
        else:
            return InferenceHistorySearchRequest(
        )
        """

    def testInferenceHistorySearchRequest(self):
        """Test InferenceHistorySearchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
