# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.flow_sessions_api import FlowSessionsApi


class TestFlowSessionsApi(unittest.TestCase):
    """FlowSessionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlowSessionsApi()

    def tearDown(self) -> None:
        pass

    def test_delete_chatbot_session_view(self) -> None:
        """Test case for delete_chatbot_session_view

        Delete Chatbot Session View
        """
        pass

    def test_get_chatbot_session_view(self) -> None:
        """Test case for get_chatbot_session_view

        Get Chatbot Session View
        """
        pass

    def test_search_chatbot_sessions_view(self) -> None:
        """Test case for search_chatbot_sessions_view

        Search Chatbot Sessions View
        """
        pass

    def test_update_chatbot_session_view(self) -> None:
        """Test case for update_chatbot_session_view

        Update Chatbot Session View
        """
        pass


if __name__ == '__main__':
    unittest.main()
