# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.integration_response import IntegrationResponse

class TestIntegrationResponse(unittest.TestCase):
    """IntegrationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IntegrationResponse:
        """Test IntegrationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IntegrationResponse`
        """
        model = IntegrationResponse()
        if include_optional:
            return IntegrationResponse(
                slug = 'api_integration',
                name = 'API Integration',
                description = 'API Integration',
                integrated_instance_cnt = 1,
                categories = [
                    'dev_tools'
                    ],
                alpha = True,
                beta = True,
                public_flow_id = ''
            )
        else:
            return IntegrationResponse(
                slug = 'api_integration',
                name = 'API Integration',
                description = 'API Integration',
                integrated_instance_cnt = 1,
                categories = [
                    'dev_tools'
                    ],
        )
        """

    def testIntegrationResponse(self):
        """Test IntegrationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
