# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.google_ads_api import GoogleAdsApi


class TestGoogleAdsApi(unittest.TestCase):
    """GoogleAdsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GoogleAdsApi()

    def tearDown(self) -> None:
        pass

    def test_add_keyword_to_group(self) -> None:
        """Test case for add_keyword_to_group

        Add Keyword To Group
        """
        pass

    def test_analyze_not_assigned_keywords(self) -> None:
        """Test case for analyze_not_assigned_keywords

        Analyze Not Assigned Keywords
        """
        pass

    def test_get_google_ads_campaigns(self) -> None:
        """Test case for get_google_ads_campaigns

        Get Google Ads Campaigns
        """
        pass

    def test_get_google_ads_customers(self) -> None:
        """Test case for get_google_ads_customers

        Get Google Ads Customers
        """
        pass

    def test_get_google_ads_groups(self) -> None:
        """Test case for get_google_ads_groups

        Get Google Ads Groups
        """
        pass

    def test_get_recommendations(self) -> None:
        """Test case for get_recommendations

        Get Recommendations
        """
        pass

    def test_import_google_ads_campaigns(self) -> None:
        """Test case for import_google_ads_campaigns

        Import Google Ads Campaigns
        """
        pass

    def test_import_google_ads_customers(self) -> None:
        """Test case for import_google_ads_customers

        Import Google Ads Customers
        """
        pass

    def test_import_google_ads_groups(self) -> None:
        """Test case for import_google_ads_groups

        Import Google Ads Groups
        """
        pass

    def test_remove_keyword_from_group(self) -> None:
        """Test case for remove_keyword_from_group

        Remove Keyword From Group
        """
        pass

    def test_update_google_ads_campaign(self) -> None:
        """Test case for update_google_ads_campaign

        Update Google Ads Campaign
        """
        pass

    def test_update_google_ads_customer_update(self) -> None:
        """Test case for update_google_ads_customer_update

        Update Google Ads Customer Update
        """
        pass

    def test_update_google_ads_group(self) -> None:
        """Test case for update_google_ads_group

        Update Google Ads Group
        """
        pass


if __name__ == '__main__':
    unittest.main()
