# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.photo_ai_api import PhotoAIApi


class TestPhotoAIApi(unittest.TestCase):
    """PhotoAIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PhotoAIApi()

    def tearDown(self) -> None:
        pass

    def test_explore(self) -> None:
        """Test case for explore

        Explore
        """
        pass

    def test_get_effects(self) -> None:
        """Test case for get_effects

        Get Effects
        """
        pass

    def test_get_styles(self) -> None:
        """Test case for get_styles

        Get Styles
        """
        pass

    def test_get_templates(self) -> None:
        """Test case for get_templates

        Get Templates
        """
        pass


if __name__ == '__main__':
    unittest.main()
