# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.o_auth_api import OAuthApi


class TestOAuthApi(unittest.TestCase):
    """OAuthApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OAuthApi()

    def tearDown(self) -> None:
        pass

    def test_oauth_authorize(self) -> None:
        """Test case for oauth_authorize

        Oauth Authorize
        """
        pass

    def test_oauth_authorize_post(self) -> None:
        """Test case for oauth_authorize_post

        Oauth Authorize Post
        """
        pass

    def test_oauth_callback(self) -> None:
        """Test case for oauth_callback

        Oauth Callback
        """
        pass

    def test_oauth_login(self) -> None:
        """Test case for oauth_login

        Oauth Login
        """
        pass

    def test_oauth_login_github(self) -> None:
        """Test case for oauth_login_github

        Oauth Login Github
        """
        pass

    def test_oauth_login_google(self) -> None:
        """Test case for oauth_login_google

        Oauth Login Google
        """
        pass

    def test_oauth_login_post(self) -> None:
        """Test case for oauth_login_post

        Oauth Login Post
        """
        pass

    def test_oauth_login_shopify(self) -> None:
        """Test case for oauth_login_shopify

        Oauth Login Shopify
        """
        pass

    def test_oauth_logout(self) -> None:
        """Test case for oauth_logout

        Oauth Logout
        """
        pass

    def test_oauth_revoke(self) -> None:
        """Test case for oauth_revoke

        Oauth Revoke
        """
        pass

    def test_oauth_token(self) -> None:
        """Test case for oauth_token

        Oauth Token
        """
        pass

    def test_oauth_userinfo(self) -> None:
        """Test case for oauth_userinfo

        Oauth Userinfo
        """
        pass

    def test_saml_callback(self) -> None:
        """Test case for saml_callback

        Saml Callback
        """
        pass


if __name__ == '__main__':
    unittest.main()
