# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.flow_cron_create_request import FlowCronCreateRequest

class TestFlowCronCreateRequest(unittest.TestCase):
    """FlowCronCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowCronCreateRequest:
        """Test FlowCronCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowCronCreateRequest`
        """
        model = FlowCronCreateRequest()
        if include_optional:
            return FlowCronCreateRequest(
                flow_id = '',
                status = 'E',
                input_text = '',
                variables = {
                    'key' : null
                    },
                interval_settings = '',
                cron_name = ''
            )
        else:
            return FlowCronCreateRequest(
                flow_id = '',
                status = 'E',
                interval_settings = '',
                cron_name = '',
        )
        """

    def testFlowCronCreateRequest(self):
        """Test FlowCronCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
