# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.hub_spot_api import HubSpotApi


class TestHubSpotApi(unittest.TestCase):
    """HubSpotApi unit test stubs"""

    def setUp(self) -> None:
        self.api = HubSpotApi()

    def tearDown(self) -> None:
        pass

    def test_get_actors(self) -> None:
        """Test case for get_actors

        Get Actors
        """
        pass


if __name__ == '__main__':
    unittest.main()
