# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.google_ads_group_response import GoogleAdsGroupResponse

class TestGoogleAdsGroupResponse(unittest.TestCase):
    """GoogleAdsGroupResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleAdsGroupResponse:
        """Test GoogleAdsGroupResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleAdsGroupResponse`
        """
        model = GoogleAdsGroupResponse()
        if include_optional:
            return GoogleAdsGroupResponse(
                workspace_id = '',
                customer_id = '',
                campaign_id = '',
                group_id = '',
                group_name = '',
                group_status = 0,
                last_update = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                action_type = 'I',
                language_code = '',
                country = ''
            )
        else:
            return GoogleAdsGroupResponse(
                workspace_id = '',
                customer_id = '',
                campaign_id = '',
                group_id = '',
                group_name = '',
                group_status = 0,
                action_type = 'I',
        )
        """

    def testGoogleAdsGroupResponse(self):
        """Test GoogleAdsGroupResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
