# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.flow_session_invocation_response import FlowSessionInvocationResponse

class TestFlowSessionInvocationResponse(unittest.TestCase):
    """FlowSessionInvocationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowSessionInvocationResponse:
        """Test FlowSessionInvocationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowSessionInvocationResponse`
        """
        model = FlowSessionInvocationResponse()
        if include_optional:
            return FlowSessionInvocationResponse(
                message_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                created_at = '',
                cached_events = [
                    flowhunt.models.flow_session_event.FlowSessionEvent(
                        workspace_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11', 
                        session_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11', 
                        event_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11', 
                        event_type = text, 
                        created_at_timestamp = '', 
                        action_type = loading, 
                        credits = 10, 
                        metadata = null, 
                        component_name = '', )
                    ]
            )
        else:
            return FlowSessionInvocationResponse(
                message_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                created_at = '',
        )
        """

    def testFlowSessionInvocationResponse(self):
        """Test FlowSessionInvocationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
