# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.faq_type import FaqType

class TestFaqType(unittest.TestCase):
    """FaqType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testFaqType(self):
        """Test FaqType"""
        # inst = FaqType()

if __name__ == '__main__':
    unittest.main()
