# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.subscription_plan import SubscriptionPlan
from typing import Optional, Set
from typing_extensions import Self

class UserPlanResponse(BaseModel):
    """
    UserPlanResponse
    """ # noqa: E501
    price_amount: StrictInt
    price_currency: StrictStr
    monthly_topup_credits: StrictInt
    current_period_end: Optional[datetime]
    subscription_plans: Dict[str, SubscriptionPlan]
    can_remove_branding: StrictBool
    __properties: ClassVar[List[str]] = ["price_amount", "price_currency", "monthly_topup_credits", "current_period_end", "subscription_plans", "can_remove_branding"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserPlanResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if current_period_end (nullable) is None
        # and model_fields_set contains the field
        if self.current_period_end is None and "current_period_end" in self.model_fields_set:
            _dict['current_period_end'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserPlanResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "price_amount": obj.get("price_amount"),
            "price_currency": obj.get("price_currency"),
            "monthly_topup_credits": obj.get("monthly_topup_credits"),
            "current_period_end": obj.get("current_period_end"),
            "subscription_plans": dict((_k, _v) for _k, _v in obj.get("subscription_plans").items()) if obj.get("subscription_plans") is not None else None,
            "can_remove_branding": obj.get("can_remove_branding")
        })
        return _obj


