# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.google_ads_customer_update_request import GoogleAdsCustomerUpdateRequest

class TestGoogleAdsCustomerUpdateRequest(unittest.TestCase):
    """GoogleAdsCustomerUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleAdsCustomerUpdateRequest:
        """Test GoogleAdsCustomerUpdateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleAdsCustomerUpdateRequest`
        """
        model = GoogleAdsCustomerUpdateRequest()
        if include_optional:
            return GoogleAdsCustomerUpdateRequest(
                language_code = '',
                country = '',
                min_queries = 56,
                cluster_strength = 56,
                min_impressions = 56,
                min_clicks = 56,
                process_negative_keywords = 'Y',
                cron_settings = '',
                action_type = 'I',
                ga_measurement_id = '',
                ga_api_secret = ''
            )
        else:
            return GoogleAdsCustomerUpdateRequest(
        )
        """

    def testGoogleAdsCustomerUpdateRequest(self):
        """Test GoogleAdsCustomerUpdateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
