# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SerpClusterGroupIntersectionsRequest(BaseModel):
    """
    SerpClusterGroupIntersectionsRequest
    """ # noqa: E501
    customer_id: StrictStr = Field(description="Customer ID of cluster")
    campaign_id: Optional[StrictStr] = None
    group_id: Optional[StrictStr] = None
    min_cluster_strength: Optional[StrictInt] = None
    suggest_other_matching_keywords: Optional[StrictBool] = None
    include_negative_keywords: Optional[StrictBool] = None
    include_all_members: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["customer_id", "campaign_id", "group_id", "min_cluster_strength", "suggest_other_matching_keywords", "include_negative_keywords", "include_all_members"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SerpClusterGroupIntersectionsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if campaign_id (nullable) is None
        # and model_fields_set contains the field
        if self.campaign_id is None and "campaign_id" in self.model_fields_set:
            _dict['campaign_id'] = None

        # set to None if group_id (nullable) is None
        # and model_fields_set contains the field
        if self.group_id is None and "group_id" in self.model_fields_set:
            _dict['group_id'] = None

        # set to None if min_cluster_strength (nullable) is None
        # and model_fields_set contains the field
        if self.min_cluster_strength is None and "min_cluster_strength" in self.model_fields_set:
            _dict['min_cluster_strength'] = None

        # set to None if suggest_other_matching_keywords (nullable) is None
        # and model_fields_set contains the field
        if self.suggest_other_matching_keywords is None and "suggest_other_matching_keywords" in self.model_fields_set:
            _dict['suggest_other_matching_keywords'] = None

        # set to None if include_negative_keywords (nullable) is None
        # and model_fields_set contains the field
        if self.include_negative_keywords is None and "include_negative_keywords" in self.model_fields_set:
            _dict['include_negative_keywords'] = None

        # set to None if include_all_members (nullable) is None
        # and model_fields_set contains the field
        if self.include_all_members is None and "include_all_members" in self.model_fields_set:
            _dict['include_all_members'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SerpClusterGroupIntersectionsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "customer_id": obj.get("customer_id"),
            "campaign_id": obj.get("campaign_id"),
            "group_id": obj.get("group_id"),
            "min_cluster_strength": obj.get("min_cluster_strength"),
            "suggest_other_matching_keywords": obj.get("suggest_other_matching_keywords"),
            "include_negative_keywords": obj.get("include_negative_keywords"),
            "include_all_members": obj.get("include_all_members")
        })
        return _obj


