# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.credits_api import CreditsApi


class TestCreditsApi(unittest.TestCase):
    """CreditsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CreditsApi()

    def tearDown(self) -> None:
        pass

    def test_get_credit_balance(self) -> None:
        """Test case for get_credit_balance

        Get Credit Balance
        """
        pass

    def test_get_workspace_credit_balance(self) -> None:
        """Test case for get_workspace_credit_balance

        Get Workspace Credit Balance
        """
        pass

    def test_search_credit_transactions(self) -> None:
        """Test case for search_credit_transactions

        Search Credit Transactions
        """
        pass

    def test_search_daily_credit_transactions(self) -> None:
        """Test case for search_daily_credit_transactions

        Search Daily Credit Transactions
        """
        pass


if __name__ == '__main__':
    unittest.main()
