# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.api_keys_api import ApiKeysApi


class TestApiKeysApi(unittest.TestCase):
    """ApiKeysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApiKeysApi()

    def tearDown(self) -> None:
        pass

    def test_create_api_key(self) -> None:
        """Test case for create_api_key

        Create Api Key
        """
        pass

    def test_delete_api_key(self) -> None:
        """Test case for delete_api_key

        Delete Api Key
        """
        pass

    def test_search_api_key(self) -> None:
        """Test case for search_api_key

        Search Api Key
        """
        pass

    def test_update_api_key(self) -> None:
        """Test case for update_api_key

        Update Api Key
        """
        pass


if __name__ == '__main__':
    unittest.main()
