# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.workspace_sso_list_response import WorkspaceSSOListResponse

class TestWorkspaceSSOListResponse(unittest.TestCase):
    """WorkspaceSSOListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkspaceSSOListResponse:
        """Test WorkspaceSSOListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorkspaceSSOListResponse`
        """
        model = WorkspaceSSOListResponse()
        if include_optional:
            return WorkspaceSSOListResponse(
                items = [
                    flowhunt.models.workspace_sso_response.WorkspaceSSOResponse(
                        workspace_id = '', 
                        provider = '', 
                        domain = '', 
                        enabled = True, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        idp_sso_url = '', 
                        idp_metadata_xml = '', 
                        idp_entity_id = '', 
                        idp_x509_cert = '', 
                        login_method = '', 
                        jit_provisioning_enabled = True, 
                        email_attribute = '', 
                        name_id_format = '', 
                        assertion_consumer_service_url = '', 
                        first_name_attribute = '', 
                        last_name_attribute = '', 
                        role_attribute = '', )
                    ]
            )
        else:
            return WorkspaceSSOListResponse(
                items = [
                    flowhunt.models.workspace_sso_response.WorkspaceSSOResponse(
                        workspace_id = '', 
                        provider = '', 
                        domain = '', 
                        enabled = True, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        idp_sso_url = '', 
                        idp_metadata_xml = '', 
                        idp_entity_id = '', 
                        idp_x509_cert = '', 
                        login_method = '', 
                        jit_provisioning_enabled = True, 
                        email_attribute = '', 
                        name_id_format = '', 
                        assertion_consumer_service_url = '', 
                        first_name_attribute = '', 
                        last_name_attribute = '', 
                        role_attribute = '', )
                    ],
        )
        """

    def testWorkspaceSSOListResponse(self):
        """Test WorkspaceSSOListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
