# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.chatbots_api import ChatbotsApi


class TestChatbotsApi(unittest.TestCase):
    """ChatbotsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ChatbotsApi()

    def tearDown(self) -> None:
        pass

    def test_create_chatbot(self) -> None:
        """Test case for create_chatbot

        Create Chatbot
        """
        pass

    def test_delete_chatbot(self) -> None:
        """Test case for delete_chatbot

        Delete Chatbot
        """
        pass

    def test_get_chatbot(self) -> None:
        """Test case for get_chatbot

        Get Chatbot
        """
        pass

    def test_search_chatbots(self) -> None:
        """Test case for search_chatbots

        Search Chatbots
        """
        pass

    def test_update_chatbot(self) -> None:
        """Test case for update_chatbot

        Update Chatbot
        """
        pass


if __name__ == '__main__':
    unittest.main()
