# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.mcp_server_create_request import MCPServerCreateRequest

class TestMCPServerCreateRequest(unittest.TestCase):
    """MCPServerCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MCPServerCreateRequest:
        """Test MCPServerCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MCPServerCreateRequest`
        """
        model = MCPServerCreateRequest()
        if include_optional:
            return MCPServerCreateRequest(
                name = 'My MCP Server',
                is_active = True,
                server_configuration = [
                    flowhunt.models.mcp_sub_server_binding.MCPSubServerBinding(
                        subserver_id = '', 
                        capabilities = [
                            flowhunt.models.mcp_capability_binding.MCPCapabilityBinding(
                                capability_id = '', )
                            ], )
                    ]
            )
        else:
            return MCPServerCreateRequest(
                name = 'My MCP Server',
                server_configuration = [
                    flowhunt.models.mcp_sub_server_binding.MCPSubServerBinding(
                        subserver_id = '', 
                        capabilities = [
                            flowhunt.models.mcp_capability_binding.MCPCapabilityBinding(
                                capability_id = '', )
                            ], )
                    ],
        )
        """

    def testMCPServerCreateRequest(self):
        """Test MCPServerCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
