# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.serp_api import SERPApi


class TestSERPApi(unittest.TestCase):
    """SERPApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SERPApi()

    def tearDown(self) -> None:
        pass

    def test_search_cluster_query(self) -> None:
        """Test case for search_cluster_query

        Search Cluster Query
        """
        pass

    def test_serp_cluster_add_queries(self) -> None:
        """Test case for serp_cluster_add_queries

        Serp Cluster Add Queries
        """
        pass

    def test_serp_cluster_delete_campaign(self) -> None:
        """Test case for serp_cluster_delete_campaign

        Serp Cluster Delete Campaign
        """
        pass

    def test_serp_cluster_delete_customer(self) -> None:
        """Test case for serp_cluster_delete_customer

        Serp Cluster Delete Customer
        """
        pass

    def test_serp_cluster_delete_group(self) -> None:
        """Test case for serp_cluster_delete_group

        Serp Cluster Delete Group
        """
        pass

    def test_serp_cluster_delete_group_queries(self) -> None:
        """Test case for serp_cluster_delete_group_queries

        Serp Cluster Delete Group Queries
        """
        pass

    def test_serp_cluster_get_graph_nodes(self) -> None:
        """Test case for serp_cluster_get_graph_nodes

        Serp Cluster Get Graph Nodes
        """
        pass

    def test_serp_cluster_get_matching_groups_to_query(self) -> None:
        """Test case for serp_cluster_get_matching_groups_to_query

        Serp Cluster Get Matching Groups To Query
        """
        pass

    def test_serp_cluster_get_related_keywords_to_query(self) -> None:
        """Test case for serp_cluster_get_related_keywords_to_query

        Serp Cluster Get Related Keywords To Query
        """
        pass

    def test_serp_cluster_split_to_sub_clusters(self) -> None:
        """Test case for serp_cluster_split_to_sub_clusters

        Serp Cluster Split To Sub Clusters
        """
        pass

    def test_serp_search(self) -> None:
        """Test case for serp_search

        Serp Search
        """
        pass

    def test_serp_volumes(self) -> None:
        """Test case for serp_volumes

        Serp Volumes
        """
        pass

    def test_serp_volumes_pingback(self) -> None:
        """Test case for serp_volumes_pingback

        Serp Volumes Pingback
        """
        pass


if __name__ == '__main__':
    unittest.main()
