# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TriggerType(str, Enum):
    """
    TriggerType
    """

    """
    allowed enum values
    """
    ON_CHAT_OPEN = 'on_chat_open'
    CUSTOM_TRIGGER = 'custom_trigger'
    CHAT_INPUT = 'chat_input'
    SLACK_MESSAGE_RECEIVED = 'slack_message_received'
    SLACK_SHORTCUTS = 'slack_shortcuts'
    ON_HUBSPOT_MESSAGE = 'on_hubspot_message'
    ON_GMAIL_MESSAGE = 'on_gmail_message'
    ON_EMAIL_MESSAGE = 'on_email_message'
    ON_OUTLOOK_MESSAGE = 'on_outlook_message'
    ON_CALENDAR_EVENT_CREATED = 'on_calendar_event_created'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TriggerType from a JSON string"""
        return cls(json.loads(json_str))


