# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.workspaces_sso_api import WorkspacesSSOApi


class TestWorkspacesSSOApi(unittest.TestCase):
    """WorkspacesSSOApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkspacesSSOApi()

    def tearDown(self) -> None:
        pass

    def test_create_workspace_sso_settings(self) -> None:
        """Test case for create_workspace_sso_settings

        Create Workspace Sso Settings
        """
        pass

    def test_delete_workspace_sso_settings(self) -> None:
        """Test case for delete_workspace_sso_settings

        Delete Workspace Sso Settings
        """
        pass

    def test_get_workspace_sso_settings(self) -> None:
        """Test case for get_workspace_sso_settings

        Get Workspace Sso Settings
        """
        pass

    def test_list_workspace_sso_settings(self) -> None:
        """Test case for list_workspace_sso_settings

        List Workspace Sso Settings
        """
        pass

    def test_update_workspace_sso_settings(self) -> None:
        """Test case for update_workspace_sso_settings

        Update Workspace Sso Settings
        """
        pass


if __name__ == '__main__':
    unittest.main()
