# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.flows_api import FlowsApi


class TestFlowsApi(unittest.TestCase):
    """FlowsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlowsApi()

    def tearDown(self) -> None:
        pass

    def test_create_chatbot_session(self) -> None:
        """Test case for create_chatbot_session

        Create Chatbot Session
        """
        pass

    def test_create_flow(self) -> None:
        """Test case for create_flow

        Create Flow
        """
        pass

    def test_create_flow_category(self) -> None:
        """Test case for create_flow_category

        Create Flow Category
        """
        pass

    def test_create_flow_cron(self) -> None:
        """Test case for create_flow_cron

        Create Flow Cron
        """
        pass

    def test_create_flow_session(self) -> None:
        """Test case for create_flow_session

        Create Flow Session
        """
        pass

    def test_delete_attachment(self) -> None:
        """Test case for delete_attachment

        Delete Attachment
        """
        pass

    def test_delete_flow(self) -> None:
        """Test case for delete_flow

        Delete Flow
        """
        pass

    def test_delete_flow_category(self) -> None:
        """Test case for delete_flow_category

        Delete Flow Category
        """
        pass

    def test_delete_flow_cron(self) -> None:
        """Test case for delete_flow_cron

        Delete Flow Cron
        """
        pass

    def test_execute_flow_cron(self) -> None:
        """Test case for execute_flow_cron

        Execute Flow Cron
        """
        pass

    def test_generate_commit_message(self) -> None:
        """Test case for generate_commit_message

        Generate Commit Message
        """
        pass

    def test_get(self) -> None:
        """Test case for get

        Get
        """
        pass

    def test_get_all_components(self) -> None:
        """Test case for get_all_components

        Get All Components
        """
        pass

    def test_get_attachments(self) -> None:
        """Test case for get_attachments

        Get Attachments
        """
        pass

    def test_get_flow_versions(self) -> None:
        """Test case for get_flow_versions

        Get Flow Versions
        """
        pass

    def test_get_invoked_flow_results(self) -> None:
        """Test case for get_invoked_flow_results

        Get Invoked Flow Results
        """
        pass

    def test_get_public_flow(self) -> None:
        """Test case for get_public_flow

        Get Public Flow
        """
        pass

    def test_get_trigger_types(self) -> None:
        """Test case for get_trigger_types

        Get Trigger Types
        """
        pass

    def test_invoke_flow(self) -> None:
        """Test case for invoke_flow

        Invoke Flow
        """
        pass

    def test_invoke_flow_response(self) -> None:
        """Test case for invoke_flow_response

        Invoke Flow Response
        """
        pass

    def test_invoke_flow_singleton(self) -> None:
        """Test case for invoke_flow_singleton

        Invoke Flow Singleton
        """
        pass

    def test_poll_flow_response(self) -> None:
        """Test case for poll_flow_response

        Poll Flow Response
        """
        pass

    def test_publish_flow(self) -> None:
        """Test case for publish_flow

        Publish Flow
        """
        pass

    def test_restore_flow_version(self) -> None:
        """Test case for restore_flow_version

        Restore Flow Version
        """
        pass

    def test_search(self) -> None:
        """Test case for search

        Search
        """
        pass

    def test_search_all(self) -> None:
        """Test case for search_all

        Search All
        """
        pass

    def test_search_flow_categories(self) -> None:
        """Test case for search_flow_categories

        Search Flow Categories
        """
        pass

    def test_search_flow_crons(self) -> None:
        """Test case for search_flow_crons

        Search Flow Crons
        """
        pass

    def test_update_flow(self) -> None:
        """Test case for update_flow

        Update Flow
        """
        pass

    def test_update_flow_category(self) -> None:
        """Test case for update_flow_category

        Update Flow Category
        """
        pass

    def test_update_flow_cron(self) -> None:
        """Test case for update_flow_cron

        Update Flow Cron
        """
        pass

    def test_upload_attachments(self) -> None:
        """Test case for upload_attachments

        Upload Attachments
        """
        pass


if __name__ == '__main__':
    unittest.main()
