# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.plan_list_item_response import PlanListItemResponse

class TestPlanListItemResponse(unittest.TestCase):
    """PlanListItemResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlanListItemResponse:
        """Test PlanListItemResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlanListItemResponse`
        """
        model = PlanListItemResponse()
        if include_optional:
            return PlanListItemResponse(
                product_id = '',
                price_id = '',
                currency = '',
                amount_monthly = 56,
                amount_yearly = 56,
                recurring = True,
                name = '',
                description = '',
                popular = True,
                monthly_credits = 56,
                features = [
                    flowhunt.models.feature_response.FeatureResponse(
                        name = '', 
                        available = True, )
                    ],
                subscription_plan = 'S',
                self_hosted = True,
                addon = True,
                addon_type = ''
            )
        else:
            return PlanListItemResponse(
                product_id = '',
                price_id = '',
                currency = '',
                amount_monthly = 56,
                recurring = True,
                name = '',
                description = '',
                popular = True,
                monthly_credits = 56,
                features = [
                    flowhunt.models.feature_response.FeatureResponse(
                        name = '', 
                        available = True, )
                    ],
                subscription_plan = 'S',
        )
        """

    def testPlanListItemResponse(self):
        """Test PlanListItemResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
