# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.integrations_api import IntegrationsApi


class TestIntegrationsApi(unittest.TestCase):
    """IntegrationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IntegrationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_integration(self) -> None:
        """Test case for create_integration

        Create Integration
        """
        pass

    def test_customer_data_request(self) -> None:
        """Test case for customer_data_request

        Customer Data Request
        """
        pass

    def test_customer_redact(self) -> None:
        """Test case for customer_redact

        Customer Redact
        """
        pass

    def test_delete_integration(self) -> None:
        """Test case for delete_integration

        Delete Integration
        """
        pass

    def test_get_actors(self) -> None:
        """Test case for get_actors

        Get Actors
        """
        pass

    def test_get_all_integrations(self) -> None:
        """Test case for get_all_integrations

        Get All Integrations
        """
        pass

    def test_get_calendars(self) -> None:
        """Test case for get_calendars

        Get Calendars
        """
        pass

    def test_get_integration(self) -> None:
        """Test case for get_integration

        Get Integration
        """
        pass

    def test_get_picker_token(self) -> None:
        """Test case for get_picker_token

        Get Picker Token
        """
        pass

    def test_get_profile_information(self) -> None:
        """Test case for get_profile_information

        Get Profile Information
        """
        pass

    def test_get_sheets(self) -> None:
        """Test case for get_sheets

        Get Sheets
        """
        pass

    def test_get_slack_channels(self) -> None:
        """Test case for get_slack_channels

        Get Slack Channels
        """
        pass

    def test_get_slack_workspaces(self) -> None:
        """Test case for get_slack_workspaces

        Get Slack Workspaces
        """
        pass

    def test_get_wordpress_post_categories(self) -> None:
        """Test case for get_wordpress_post_categories

        Get Wordpress Post Categories
        """
        pass

    def test_get_wordpress_post_tags(self) -> None:
        """Test case for get_wordpress_post_tags

        Get Wordpress Post Tags
        """
        pass

    def test_get_wordpress_sites(self) -> None:
        """Test case for get_wordpress_sites

        Get Wordpress Sites
        """
        pass

    def test_integration_callback(self) -> None:
        """Test case for integration_callback

        Integration Callback
        """
        pass

    def test_search_integrations(self) -> None:
        """Test case for search_integrations

        Search Integrations
        """
        pass

    def test_shop_redact(self) -> None:
        """Test case for shop_redact

        Shop Redact
        """
        pass

    def test_update_admin_consent(self) -> None:
        """Test case for update_admin_consent

        Update Admin Consent
        """
        pass


if __name__ == '__main__':
    unittest.main()
