# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.tracking_api import TrackingApi


class TestTrackingApi(unittest.TestCase):
    """TrackingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TrackingApi()

    def tearDown(self) -> None:
        pass

    def test_search_events(self) -> None:
        """Test case for search_events

        Search Events
        """
        pass

    def test_search_links(self) -> None:
        """Test case for search_links

        Search Links
        """
        pass

    def test_search_sources(self) -> None:
        """Test case for search_sources

        Search Sources
        """
        pass

    def test_track_click(self) -> None:
        """Test case for track_click

        Track Click
        """
        pass

    def test_track_event(self) -> None:
        """Test case for track_event

        Track Event
        """
        pass

    def test_track_link(self) -> None:
        """Test case for track_link

        Track Link
        """
        pass


if __name__ == '__main__':
    unittest.main()
