# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.flow_detail_response import FlowDetailResponse

class TestFlowDetailResponse(unittest.TestCase):
    """FlowDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowDetailResponse:
        """Test FlowDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowDetailResponse`
        """
        model = FlowDetailResponse()
        if include_optional:
            return FlowDetailResponse(
                id = '123e4567-e89b-12d3-a456-426614174000',
                name = 'Flow 1',
                description = 'Flow 1 description',
                detailed_description = '',
                config = flowhunt.models.flow_config.FlowConfig(
                    nodes = [
                        null
                        ], 
                    edges = [
                        null
                        ], ),
                flow_type = p,
                executed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                category_id = '',
                branch = 'P',
                enable_cache = True,
                draft_version_nr = 56,
                prod_version_nr = 56,
                last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return FlowDetailResponse(
                id = '123e4567-e89b-12d3-a456-426614174000',
                name = 'Flow 1',
                description = 'Flow 1 description',
                config = flowhunt.models.flow_config.FlowConfig(
                    nodes = [
                        null
                        ], 
                    edges = [
                        null
                        ], ),
                flow_type = p,
                branch = 'P',
                enable_cache = True,
        )
        """

    def testFlowDetailResponse(self):
        """Test FlowDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
