# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.image_inference_request import ImageInferenceRequest

class TestImageInferenceRequest(unittest.TestCase):
    """ImageInferenceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageInferenceRequest:
        """Test ImageInferenceRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImageInferenceRequest`
        """
        model = ImageInferenceRequest()
        if include_optional:
            return ImageInferenceRequest(
                base_model = 'flux-dev',
                prompt = '',
                image_fts = [
                    ''
                    ],
                number_of_outputs = 56,
                aspect_ratio = '1:1',
                steps = 56,
                guidance_scale = 0.0,
                styles = [
                    ''
                    ],
                effects = [
                    ''
                    ],
                use_ai_agent = True
            )
        else:
            return ImageInferenceRequest(
                base_model = 'flux-dev',
                prompt = '',
                image_fts = [
                    ''
                    ],
        )
        """

    def testImageInferenceRequest(self):
        """Test ImageInferenceRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
