# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.mcp_servers_api import MCPServersApi


class TestMCPServersApi(unittest.TestCase):
    """MCPServersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MCPServersApi()

    def tearDown(self) -> None:
        pass

    def test_create_mcp_server(self) -> None:
        """Test case for create_mcp_server

        Create Mcp Server
        """
        pass

    def test_delete_mcp_server(self) -> None:
        """Test case for delete_mcp_server

        Delete Mcp Server
        """
        pass

    def test_get_all_mcp_subservers(self) -> None:
        """Test case for get_all_mcp_subservers

        Get All Mcp Subservers
        """
        pass

    def test_get_mcp_server(self) -> None:
        """Test case for get_mcp_server

        Get Mcp Server
        """
        pass

    def test_search_mcp_servers(self) -> None:
        """Test case for search_mcp_servers

        Search Mcp Servers
        """
        pass

    def test_update_mcp_server(self) -> None:
        """Test case for update_mcp_server

        Update Mcp Server
        """
        pass


if __name__ == '__main__':
    unittest.main()
