# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.vector_documents_task_response import VectorDocumentsTaskResponse

class TestVectorDocumentsTaskResponse(unittest.TestCase):
    """VectorDocumentsTaskResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VectorDocumentsTaskResponse:
        """Test VectorDocumentsTaskResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VectorDocumentsTaskResponse`
        """
        model = VectorDocumentsTaskResponse()
        if include_optional:
            return VectorDocumentsTaskResponse(
                id = '',
                status = 'PENDING',
                result = [
                    flowhunt.models.vector_document_response.VectorDocumentResponse(
                        document_id = '00000000-0000-0000-0000-000000000000', 
                        workspace_id = '00000000-0000-0000-0000-000000000000', 
                        document_type = U, 
                        point_id = '00000000-0000-0000-0000-000000000000', 
                        pointer_position = 1, 
                        pointer_type = C, 
                        schema_type = '', 
                        kb_key = '00000000-0000-0000-0000-000000000000', 
                        vector = [
                            1.337
                            ], 
                        vector_id = 0, 
                        data = null, )
                    ],
                error_message = ''
            )
        else:
            return VectorDocumentsTaskResponse(
                id = '',
                status = 'PENDING',
        )
        """

    def testVectorDocumentsTaskResponse(self):
        """Test VectorDocumentsTaskResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
