# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.secrets_api import SecretsApi


class TestSecretsApi(unittest.TestCase):
    """SecretsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SecretsApi()

    def tearDown(self) -> None:
        pass

    def test_create_secret(self) -> None:
        """Test case for create_secret

        Create Secret
        """
        pass

    def test_delete_secret(self) -> None:
        """Test case for delete_secret

        Delete Secret
        """
        pass

    def test_get_secret(self) -> None:
        """Test case for get_secret

        Get Secret
        """
        pass

    def test_search_secret(self) -> None:
        """Test case for search_secret

        Search Secret
        """
        pass

    def test_update_secret(self) -> None:
        """Test case for update_secret

        Update Secret
        """
        pass


if __name__ == '__main__':
    unittest.main()
