# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.google_ads_keyword_recommendation import GoogleAdsKeywordRecommendation

class TestGoogleAdsKeywordRecommendation(unittest.TestCase):
    """GoogleAdsKeywordRecommendation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleAdsKeywordRecommendation:
        """Test GoogleAdsKeywordRecommendation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleAdsKeywordRecommendation`
        """
        model = GoogleAdsKeywordRecommendation()
        if include_optional:
            return GoogleAdsKeywordRecommendation(
                workspace_id = '',
                customer_id = '',
                campaign_id = '',
                campaign_name = '',
                group_id = '',
                group_name = '',
                keyword_id = '',
                keyword = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                recommendations = [
                    flowhunt.models.google_ads_recommendation.GoogleAdsRecommendation(
                        recommendation_type = 'A', 
                        campaign_id = '', 
                        campaign_name = '', 
                        group_id = '', 
                        group_name = '', 
                        action_status = 'E', 
                        confidence = 'H', )
                    ]
            )
        else:
            return GoogleAdsKeywordRecommendation(
                workspace_id = '',
                customer_id = '',
                campaign_id = '',
                campaign_name = '',
                group_id = '',
                group_name = '',
                keyword_id = '',
                keyword = '',
        )
        """

    def testGoogleAdsKeywordRecommendation(self):
        """Test GoogleAdsKeywordRecommendation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
