# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.documents_api import DocumentsApi


class TestDocumentsApi(unittest.TestCase):
    """DocumentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DocumentsApi()

    def tearDown(self) -> None:
        pass

    def test_create_document_category(self) -> None:
        """Test case for create_document_category

        Create Document Category
        """
        pass

    def test_create_faq(self) -> None:
        """Test case for create_faq

        Create Faq
        """
        pass

    def test_delete_document(self) -> None:
        """Test case for delete_document

        Delete Document
        """
        pass

    def test_delete_document_category(self) -> None:
        """Test case for delete_document_category

        Delete Document Category
        """
        pass

    def test_delete_faq(self) -> None:
        """Test case for delete_faq

        Delete Faq
        """
        pass

    def test_download_binary_document(self) -> None:
        """Test case for download_binary_document

        Download Binary Document
        """
        pass

    def test_download_text_document(self) -> None:
        """Test case for download_text_document

        Download Text Document
        """
        pass

    def test_import_faq(self) -> None:
        """Test case for import_faq

        Import Faq
        """
        pass

    def test_search_document_categories(self) -> None:
        """Test case for search_document_categories

        Search Document Categories
        """
        pass

    def test_search_documents(self) -> None:
        """Test case for search_documents

        Search Documents
        """
        pass

    def test_search_faqs(self) -> None:
        """Test case for search_faqs

        Search Faqs
        """
        pass

    def test_update_document(self) -> None:
        """Test case for update_document

        Update Document
        """
        pass

    def test_update_document_category(self) -> None:
        """Test case for update_document_category

        Update Document Category
        """
        pass

    def test_update_faq(self) -> None:
        """Test case for update_faq

        Update Faq
        """
        pass

    def test_upload_document(self) -> None:
        """Test case for upload_document

        Upload Document
        """
        pass

    def test_upload_from_url_document(self) -> None:
        """Test case for upload_from_url_document

        Upload From Url Document
        """
        pass


if __name__ == '__main__':
    unittest.main()
