# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.fine_tunings_api import FineTuningsApi


class TestFineTuningsApi(unittest.TestCase):
    """FineTuningsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FineTuningsApi()

    def tearDown(self) -> None:
        pass

    def test_create_image_ft(self) -> None:
        """Test case for create_image_ft

        Create Image Ft
        """
        pass

    def test_delete_file_ft(self) -> None:
        """Test case for delete_file_ft

        Delete File Ft
        """
        pass

    def test_delete_image_ft(self) -> None:
        """Test case for delete_image_ft

        Delete Image Ft
        """
        pass

    def test_generate_image_prompt(self) -> None:
        """Test case for generate_image_prompt

        Generate Image Prompt
        """
        pass

    def test_generate_images(self) -> None:
        """Test case for generate_images

        Generate Images
        """
        pass

    def test_get_file_ft(self) -> None:
        """Test case for get_file_ft

        Get File Ft
        """
        pass

    def test_get_inference_results(self) -> None:
        """Test case for get_inference_results

        Get Inference Results
        """
        pass

    def test_handle_replicate_webhook(self) -> None:
        """Test case for handle_replicate_webhook

        Handle Replicate Webhook
        """
        pass

    def test_search_image_fts(self) -> None:
        """Test case for search_image_fts

        Search Image Fts
        """
        pass

    def test_search_inference_history(self) -> None:
        """Test case for search_inference_history

        Search Inference History
        """
        pass

    def test_update_image_ft(self) -> None:
        """Test case for update_image_ft

        Update Image Ft
        """
        pass

    def test_upload_image_ft(self) -> None:
        """Test case for upload_image_ft

        Upload Image Ft
        """
        pass


if __name__ == '__main__':
    unittest.main()
