# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.media_api import MediaApi


class TestMediaApi(unittest.TestCase):
    """MediaApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MediaApi()

    def tearDown(self) -> None:
        pass

    def test_get_transcript(self) -> None:
        """Test case for get_transcript

        Get Transcript
        """
        pass

    def test_get_transcript_result(self) -> None:
        """Test case for get_transcript_result

        Get Transcript Result
        """
        pass

    def test_get_youtube_transcript(self) -> None:
        """Test case for get_youtube_transcript

        Get Youtube Transcript
        """
        pass


if __name__ == '__main__':
    unittest.main()
