# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.observability_driver_api import ObservabilityDriverApi


class TestObservabilityDriverApi(unittest.TestCase):
    """ObservabilityDriverApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ObservabilityDriverApi()

    def tearDown(self) -> None:
        pass

    def test_activate_langfuse_observability_driver(self) -> None:
        """Test case for activate_langfuse_observability_driver

        Activate Langfuse Observability Driver
        """
        pass

    def test_delete_observability_driver(self) -> None:
        """Test case for delete_observability_driver

        Delete Observability Driver
        """
        pass

    def test_get_observability_driver(self) -> None:
        """Test case for get_observability_driver

        Get Observability Driver
        """
        pass

    def test_get_observability_driver_workspace(self) -> None:
        """Test case for get_observability_driver_workspace

        Get Observability Driver Workspace
        """
        pass

    def test_update_langfuse_observability_driver(self) -> None:
        """Test case for update_langfuse_observability_driver

        Update Langfuse Observability Driver
        """
        pass


if __name__ == '__main__':
    unittest.main()
