# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.workspaces_api import WorkspacesApi


class TestWorkspacesApi(unittest.TestCase):
    """WorkspacesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkspacesApi()

    def tearDown(self) -> None:
        pass

    def test_add_workspace_user(self) -> None:
        """Test case for add_workspace_user

        Add Workspace User
        """
        pass

    def test_create_workspace(self) -> None:
        """Test case for create_workspace

        Create Workspace
        """
        pass

    def test_delete_workspace(self) -> None:
        """Test case for delete_workspace

        Delete Workspace
        """
        pass

    def test_delete_workspace_user(self) -> None:
        """Test case for delete_workspace_user

        Delete Workspace User
        """
        pass

    def test_get_workspace(self) -> None:
        """Test case for get_workspace

        Get Workspace
        """
        pass

    def test_search_my_workspaces(self) -> None:
        """Test case for search_my_workspaces

        Search My Workspaces
        """
        pass

    def test_search_workspace_users(self) -> None:
        """Test case for search_workspace_users

        Search Workspace Users
        """
        pass

    def test_update_workspace(self) -> None:
        """Test case for update_workspace

        Update Workspace
        """
        pass

    def test_update_workspace_user(self) -> None:
        """Test case for update_workspace_user

        Update Workspace User
        """
        pass


if __name__ == '__main__':
    unittest.main()
