# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.shopify_api import ShopifyApi


class TestShopifyApi(unittest.TestCase):
    """ShopifyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ShopifyApi()

    def tearDown(self) -> None:
        pass

    def test_customer_data_request(self) -> None:
        """Test case for customer_data_request

        Customer Data Request
        """
        pass

    def test_customer_redact(self) -> None:
        """Test case for customer_redact

        Customer Redact
        """
        pass

    def test_shop_redact(self) -> None:
        """Test case for shop_redact

        Shop Redact
        """
        pass


if __name__ == '__main__':
    unittest.main()
