# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.shop_redact_payload import ShopRedactPayload

class TestShopRedactPayload(unittest.TestCase):
    """ShopRedactPayload unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopRedactPayload:
        """Test ShopRedactPayload
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopRedactPayload`
        """
        model = ShopRedactPayload()
        if include_optional:
            return ShopRedactPayload(
                shop_id = 56,
                shop_domain = ''
            )
        else:
            return ShopRedactPayload(
                shop_id = 56,
                shop_domain = '',
        )
        """

    def testShopRedactPayload(self):
        """Test ShopRedactPayload"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
