# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.flow_assistant_api import FlowAssistantApi


class TestFlowAssistantApi(unittest.TestCase):
    """FlowAssistantApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlowAssistantApi()

    def tearDown(self) -> None:
        pass

    def test_apply_flow_assistant_changes(self) -> None:
        """Test case for apply_flow_assistant_changes

        Apply Flow Assistant Changes
        """
        pass

    def test_create_flow_assistant_session(self) -> None:
        """Test case for create_flow_assistant_session

        Create Flow Assistant Session
        """
        pass

    def test_invoke_flow_assistant_response(self) -> None:
        """Test case for invoke_flow_assistant_response

        Invoke Flow Assistant Response
        """
        pass

    def test_poll_flow_assistant_response(self) -> None:
        """Test case for poll_flow_assistant_response

        Poll Flow Assistant Response
        """
        pass

    def test_reject_flow_assistant_changes(self) -> None:
        """Test case for reject_flow_assistant_changes

        Reject Flow Assistant Changes
        """
        pass


if __name__ == '__main__':
    unittest.main()
