# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.chatbot_response import ChatbotResponse

class TestChatbotResponse(unittest.TestCase):
    """ChatbotResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatbotResponse:
        """Test ChatbotResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatbotResponse`
        """
        model = ChatbotResponse()
        if include_optional:
            return ChatbotResponse(
                workspace_id = '',
                chatbot_id = '',
                title = 'Tenant 1',
                description = '',
                flow_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                status = 'A',
                url_suffix = '',
                theme = '',
                max_window_size = '',
                msg_rpm = 56,
                msg_ip_rpm = 56,
                chatbot_description = '',
                show_chatbot_header = True,
                chat_bubble_bg_color = '',
                chat_bubble_icon_color = '',
                chat_bubble_img_url = '',
                chatbot_theme = '',
                chatbot_position = '',
                message_placeholder = '',
                chatbot_header_text = '',
                chatbot_header_logo_url = '',
                assistant_avatar_image_url = '',
                remove_branding = True,
                chatbot_style = '',
                session_message_history = True,
                chatbot_bubble_size = 56,
                message_header_logo_url = ''
            )
        else:
            return ChatbotResponse(
                workspace_id = '',
                chatbot_id = '',
                title = 'Tenant 1',
                flow_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                status = 'A',
        )
        """

    def testChatbotResponse(self):
        """Test ChatbotResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
