# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AspecRatio(str, Enum):
    """
    AspecRatio
    """

    """
    allowed enum values
    """
    ENUM_1_COLON_1 = '1:1'
    ENUM_16_COLON_9 = '16:9'
    ENUM_21_COLON_9 = '21:9'
    ENUM_3_COLON_2 = '3:2'
    ENUM_2_COLON_3 = '2:3'
    ENUM_4_COLON_5 = '4:5'
    ENUM_5_COLON_4 = '5:4'
    ENUM_3_COLON_4 = '3:4'
    ENUM_4_COLON_3 = '4:3'
    ENUM_9_COLON_16 = '9:16'
    ENUM_9_COLON_21 = '9:21'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AspecRatio from a JSON string"""
        return cls(json.loads(json_str))


