# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.tracking_event_create_requests import TrackingEventCreateRequests

class TestTrackingEventCreateRequests(unittest.TestCase):
    """TrackingEventCreateRequests unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TrackingEventCreateRequests:
        """Test TrackingEventCreateRequests
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TrackingEventCreateRequests`
        """
        model = TrackingEventCreateRequests()
        if include_optional:
            return TrackingEventCreateRequests(
                events = [
                    flowhunt.models.tracking_event_create_request.TrackingEventCreateRequest(
                        event_name = '', 
                        unique_id = '', 
                        event_value = 1.337, 
                        currency = '', 
                        event_data = [
                            flowhunt.models.tracking_event_data.TrackingEventData(
                                key = '', 
                                value_text = '', 
                                value_number = 1.337, 
                                value_boolean = True, 
                                value_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        link_ids = [
                            ''
                            ], 
                        valid_until = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        conversion_action_id = '', 
                        include_in_conversions_metric = True, 
                        url = '', )
                    ],
                unique_id = '',
                fp = '',
                session_id = '',
                with_address = True,
                ga = ''
            )
        else:
            return TrackingEventCreateRequests(
                events = [
                    flowhunt.models.tracking_event_create_request.TrackingEventCreateRequest(
                        event_name = '', 
                        unique_id = '', 
                        event_value = 1.337, 
                        currency = '', 
                        event_data = [
                            flowhunt.models.tracking_event_data.TrackingEventData(
                                key = '', 
                                value_text = '', 
                                value_number = 1.337, 
                                value_boolean = True, 
                                value_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        link_ids = [
                            ''
                            ], 
                        valid_until = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        conversion_action_id = '', 
                        include_in_conversions_metric = True, 
                        url = '', )
                    ],
        )
        """

    def testTrackingEventCreateRequests(self):
        """Test TrackingEventCreateRequests"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
