# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DocumentType(str, Enum):
    """
    DocumentType
    """

    """
    allowed enum values
    """
    PDF = 'PDF'
    DOCX = 'DOCX'
    MD = 'MD'
    TXT = 'TXT'
    HTML = 'HTML'
    YT = 'YT'
    UN = 'UN'
    MP3 = 'MP3'
    FLAC = 'FLAC'
    MP4 = 'MP4'
    MPEG = 'MPEG'
    MPGA = 'MPGA'
    M4A = 'M4A'
    OGG = 'OGG'
    WAV = 'WAV'
    WEBM = 'WEBM'
    JPEG = 'JPEG'
    JPG = 'JPG'
    PNG = 'PNG'
    GIF = 'GIF'
    WEBP = 'WEBP'
    CSV = 'CSV'
    XML = 'XML'
    JSON = 'JSON'
    GOOGLE_DOCS = 'GOOGLE_DOCS'
    GOOGLE_SHEETS = 'GOOGLE_SHEETS'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DocumentType from a JSON string"""
        return cls(json.loads(json_str))


