# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.microsoft_outlook_api import MicrosoftOutlookApi


class TestMicrosoftOutlookApi(unittest.TestCase):
    """MicrosoftOutlookApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MicrosoftOutlookApi()

    def tearDown(self) -> None:
        pass

    def test_update_admin_consent(self) -> None:
        """Test case for update_admin_consent

        Update Admin Consent
        """
        pass


if __name__ == '__main__':
    unittest.main()
