# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.google_api import GoogleApi


class TestGoogleApi(unittest.TestCase):
    """GoogleApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GoogleApi()

    def tearDown(self) -> None:
        pass

    def test_get_calendars(self) -> None:
        """Test case for get_calendars

        Get Calendars
        """
        pass

    def test_get_picker_token(self) -> None:
        """Test case for get_picker_token

        Get Picker Token
        """
        pass

    def test_get_sheets(self) -> None:
        """Test case for get_sheets

        Get Sheets
        """
        pass


if __name__ == '__main__':
    unittest.main()
