# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.flow_version_history_response import FlowVersionHistoryResponse

class TestFlowVersionHistoryResponse(unittest.TestCase):
    """FlowVersionHistoryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowVersionHistoryResponse:
        """Test FlowVersionHistoryResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowVersionHistoryResponse`
        """
        model = FlowVersionHistoryResponse()
        if include_optional:
            return FlowVersionHistoryResponse(
                id = '123e4567-e89b-12d3-a456-426614174000',
                name = 'Flow 1',
                description = 'Flow 1 description',
                version_nr = 56,
                flow_type = p,
                executed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                category_id = '',
                enable_cache = True,
                user = flowhunt.models.user_response.UserResponse(
                    user_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384', 
                    email = 'test@test.com', 
                    username = 'John Doe', 
                    is_active = True, 
                    avatar_url = '', 
                    api_key_workspace_id = '', 
                    product_plans = {
                        'key' : 'S'
                        }, ),
                branch = 'P',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                commit_title = ''
            )
        else:
            return FlowVersionHistoryResponse(
                id = '123e4567-e89b-12d3-a456-426614174000',
                name = 'Flow 1',
                description = 'Flow 1 description',
                flow_type = p,
                enable_cache = True,
                branch = 'P',
        )
        """

    def testFlowVersionHistoryResponse(self):
        """Test FlowVersionHistoryResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
