# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.image_ft_update_request import ImageFTUpdateRequest

class TestImageFTUpdateRequest(unittest.TestCase):
    """ImageFTUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageFTUpdateRequest:
        """Test ImageFTUpdateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImageFTUpdateRequest`
        """
        model = ImageFTUpdateRequest()
        if include_optional:
            return ImageFTUpdateRequest(
                name = 'Fine tuning 1',
                steps = 56,
                lora_rank = 56,
                training_images = [image1.jpg, image2.jpg],
                cover_image = 'cover.jpg'
            )
        else:
            return ImageFTUpdateRequest(
                name = 'Fine tuning 1',
                training_images = [image1.jpg, image2.jpg],
                cover_image = 'cover.jpg',
        )
        """

    def testImageFTUpdateRequest(self):
        """Test ImageFTUpdateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
