# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FlowEventActionType(str, Enum):
    """
    FlowEventActionType
    """

    """
    allowed enum values
    """
    LOADING = 'loading'
    MESSAGE = 'message'
    TOOL_CALL = 'tool_call'
    TASK_RESPONSE = 'task_response'
    FAILED = 'failed'
    ADD_COMPONENT = 'add_component'
    DELETE_COMPONENT = 'delete_component'
    CONNECT_COMPONENTS = 'connect_components'
    UPDATE_COMPONENT = 'update_component'
    ADD_CONNECTION = 'add_connection'
    DELETE_CONNECTION = 'delete_connection'
    CREATE_BLANK_FLOW = 'create_blank_flow'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FlowEventActionType from a JSON string"""
        return cls(json.loads(json_str))


